@@ -11,6 +11,6 @@ def to_camel_case(snake_case_string: str) -> str:
     return str(_to_camel_case(snake_case_string))
 
 
-def camelize(d: dict[str, Any]) -> dict[str, Any]:
+def camelize(d: dict[str, Any] | list[dict[str, Any]]) -> dict[str, Any] | list[dict[str, Any]]:
     """Converts {'some_thing': {'having_value': 'like_so'}} to {'someThing': {'havingValue': 'like_so'}}."""
     return _camelize(d)
